@@ -1,6 +1,7 @@
 from PythonPals.Button import *
-
-import questions
+#import Button
+from PythonPals.questions import *
+#import questions
 import pygame
 import pygame.gfxdraw
 import textwrap
